Module: PriceHubble::Client::Utils::Request

Extended by:
ActiveSupport::Concern
Included in:
Base
Defined in:
lib/price_hubble/client/utils/request.rb

Overview

Some helpers to prepare requests in a general way.

Constant Summary collapse

CONTENT_TYPE =

A common HTTP content type to symbol mapping for correct header settings.

{
  json: 'application/json',
  multipart: 'multipart/form-data',
  url_encoded: 'application/x-www-form-urlencoded'
}.freeze