Module: PriceHubble::Concern::Attributes
- Extended by:
- ActiveSupport::Concern
- Included in:
- BaseEntity
- Defined in:
- lib/price_hubble/entity/concern/attributes.rb,
lib/price_hubble/entity/concern/attributes/enum.rb,
lib/price_hubble/entity/concern/attributes/range.rb,
lib/price_hubble/entity/concern/attributes/date_array.rb,
lib/price_hubble/entity/concern/attributes/string_inquirer.rb
Overview
An ActiveRecord-like attribute management feature, with the exception that the attributes are not generated through a schema file, but are defined inline the entity class.
Defined Under Namespace
Modules: DateArray, Enum, Range, StringInquirer